@@ -2,6 +2,7 @@
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
+from django.http import Http404
 from django.template.defaultfilters import slugify
 from django.utils import timezone
 from django.utils.dateparse import parse_datetime
@@ -11,12 +12,10 @@ from rest_framework import (
     filters,
     status,
     viewsets,
-    routers,
-    mixins
+    routers
 )
 
 from rest_framework.response import Response
-from rest_framework.views import APIView
 
 from elastimorphic.models import polymorphic_indexable_registry
 
@@ -50,7 +49,10 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
         if hasattr(self, "object"):
             klass = self.object.__class__
         elif "doctype" in self.request.REQUEST:
-            klass = Content.get_doctypes()[self.request.REQUEST["doctype"]]
+            try:
+                klass = Content.get_doctypes()[self.request.REQUEST["doctype"]]
+            except KeyError:
+                raise Http404
 
         if hasattr(klass, "get_serializer_class"):
             return klass.get_serializer_class()
@@ -96,7 +98,7 @@ class ContentViewSet(UncachedResponse, viewsets.ModelViewSet):
                         filter_query = [slugify(f) for f in filter_query]
 
                     search_kwargs[field_name] = filter_query
-        
+
         self.object_list = self.model.search_objects.search(**search_kwargs).full()
 
         # Switch between paginated or standard style responses
@@ -255,21 +257,21 @@ class LogEntryViewSet(UncachedResponse, viewsets.ModelViewSet):
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
 
 
-class MeView(viewsets.ViewSet):
+class MeView(UncachedResponse, viewsets.ViewSet):
 
     def list(self, request, format=None):
-        data = {
-            "id": request.user.id,
-            "username": request.user.get_username()
-        }
-        try:
-            data["full_name"] = request.user.get_full_name()
-        except NotImplemented:
-            pass
-        try:
-            data["short_name"] = request.user.get_short_name()
-        except NotImplemented:
-            pass
+        data = {"id": request.user.id}
+
+        if request.user.is_authenticated():
+            data["username"] = request.user.get_username()
+            try:
+                data["full_name"] = request.user.get_full_name()
+            except NotImplemented:
+                pass
+            try:
+                data["short_name"] = request.user.get_short_name()
+            except NotImplemented:
+                pass
 
         return Response(data)
 
