@@ -40,7 +40,7 @@ class Migration(SchemaMigration):
             ('title', self.gf('django.db.models.fields.CharField')(max_length=512)),
             ('slug', self.gf('django.db.models.fields.SlugField')(default='', max_length=50, blank=True)),
             ('description', self.gf('django.db.models.fields.TextField')(default='', max_length=1024, blank=True)),
-            ('image', self.gf('betty.cropped.fields.ImageField')(default=None, null=True, blank=True)),
+            ('image', self.gf('djbetty.fields.ImageField')(default=None, null=True, blank=True)),
             ('feature_type', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
             ('subhead', self.gf('django.db.models.fields.CharField')(max_length=255, null=True, blank=True)),
             ('indexed', self.gf('django.db.models.fields.BooleanField')(default=True)),
@@ -105,7 +105,7 @@ class Migration(SchemaMigration):
             'description': ('django.db.models.fields.TextField', [], {'default': "''", 'max_length': '1024', 'blank': 'True'}),
             'feature_type': ('django.db.models.fields.CharField', [], {'max_length': '255', 'null': 'True', 'blank': 'True'}),
             u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'image': ('betty.cropped.fields.ImageField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
+            'image': ('djbetty.fields.ImageField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
             'indexed': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
             'last_modified': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now', 'auto_now': 'True', 'blank': 'True'}),
             'polymorphic_ctype': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "u'polymorphic_content.content_set'", 'null': 'True', 'to': u"orm['contenttypes.ContentType']"}),
